(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "tslib", "rollun-ts-rql/dist/Query", "rollun-ts-rql/dist/nodes/Limit", "./dataUpdater/DatastoreDataUpdater", "./dataUpdater/DatastoreCountUpdater", "../queryManager/QueryManager", "rollun-ts-datastore/dist/HttpDatastore", "./DialogController"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require("tslib");
    var Query_1 = require("rollun-ts-rql/dist/Query");
    var Limit_1 = require("rollun-ts-rql/dist/nodes/Limit");
    var DatastoreDataUpdater_1 = require("./dataUpdater/DatastoreDataUpdater");
    var DatastoreCountUpdater_1 = require("./dataUpdater/DatastoreCountUpdater");
    var QueryManager_1 = require("../queryManager/QueryManager");
    var HttpDatastore_1 = require("rollun-ts-datastore/dist/HttpDatastore");
    var DialogController_1 = require("./DialogController");
    var QueryAppDialogNames;
    (function (QueryAppDialogNames) {
        QueryAppDialogNames["addNewItemDialog"] = "addNewItemDialog";
        QueryAppDialogNames["editSelectedRowDialog"] = "editSelectedRowDialog";
        QueryAppDialogNames["editQueryDialog"] = "editQueryDialog";
    })(QueryAppDialogNames = exports.QueryAppDialogNames || (exports.QueryAppDialogNames = {}));
    var QueryAppContext = /** @class */ (function () {
        function QueryAppContext(invalidator, initialState) {
            var _this = this;
            this._invalidator = invalidator;
            this._grid = initialState.grid;
            this._queryManager = new QueryManager_1.default();
            this._queryManager.setQuery(new Query_1.default({ limit: new Limit_1.default(20, 0) }));
            this._datastore = new HttpDatastore_1.default(initialState.datastoreUrl);
            this._dataStoreDataUpdater = new DatastoreDataUpdater_1.default(this._datastore);
            this._countDataUpdater = new DatastoreCountUpdater_1.default(this._datastore);
            this._fieldsConfig = initialState.fieldsConfig || [];
            var addNewItemDialogId = QueryAppDialogNames.addNewItemDialog; // FIXME: why can`t i properly use enums in dialogController constructor params?
            var editSelectedRowDialogId = QueryAppDialogNames.editSelectedRowDialog;
            var editQueryDialogId = QueryAppDialogNames.editQueryDialog;
            var initialStatus = {};
            initialStatus[addNewItemDialogId] = { shown: false };
            initialStatus[editSelectedRowDialogId] = { shown: false };
            initialStatus[editQueryDialogId] = { shown: false };
            this._dialogs = new DialogController_1.default(invalidator, initialStatus);
            setTimeout(function () {
                _this.reloadGridData();
            }, 1);
        }
        Object.defineProperty(QueryAppContext.prototype, "query", {
            get: function () {
                return this._queryManager.getQuery();
            },
            set: function (query) {
                this._queryManager.setQuery(query);
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "grid", {
            get: function () {
                return this._grid;
            },
            set: function (gridValues) {
                this._grid = gridValues;
                this._invalidator();
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "datastoreData", {
            get: function () {
                return this._dataStoreDataUpdater.data;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "countData", {
            get: function () {
                return this._countDataUpdater.data;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "datastoreDataLoadingStatus", {
            get: function () {
                return this._dataStoreDataUpdater.loadingStatus;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "countDataLoadingStatus", {
            get: function () {
                return this._countDataUpdater.loadingStatus;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "idArray", {
            get: function () {
                return this._idArray;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "fieldsConfig", {
            get: function () {
                return this._fieldsConfig;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "selectedGridRowIndex", {
            get: function () {
                return this._grid.selectedRowIndex;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryAppContext.prototype, "dialogs", {
            get: function () {
                return this._dialogs;
            },
            enumerable: true,
            configurable: true
        });
        QueryAppContext.prototype.reloadGridData = function () {
            var _this = this;
            this._dataStoreDataUpdater.query = this._queryManager.getQuery();
            this._dataStoreDataUpdater.updateData().then(function () {
                _this._invalidator();
            });
            this._countDataUpdater.query = this._queryManager.getQuery();
            this._countDataUpdater.updateData().then(function () {
                _this._idArray = _this.datastoreData.map(function (item) { return String(item.id); });
                _this._invalidator();
            });
            this._invalidator();
        };
        QueryAppContext.prototype.setQueryLimit = function (limitNode) {
            this._queryManager.appendQuery(limitNode);
            this.reloadGridData();
        };
        QueryAppContext.prototype.setQueryQuery = function (queryQuery) {
            this._queryManager.appendQuery(queryQuery);
            this.reloadGridData();
        };
        QueryAppContext.prototype.removeQueryQuery = function () {
            var oldQuery = this._queryManager.getQuery();
            this._queryManager.setQuery(new Query_1.default({
                select: oldQuery.selectNode,
                sort: oldQuery.sortNode,
                limit: oldQuery.limitNode,
            }));
            this.reloadGridData();
        };
        QueryAppContext.prototype.changeCellValue = function (rowIndex, columnIndex, value) {
            var _this = this;
            var itemToUpdate = {
                id: this._idArray[rowIndex],
            };
            var fieldName = Object.keys(this.datastoreData[0])[columnIndex];
            itemToUpdate[fieldName] = value;
            this._datastore.update(itemToUpdate).then(function () {
                _this.reloadGridData();
            });
        };
        QueryAppContext.prototype.changeRowValue = function (rowIndex, changedItem) {
            var _this = this;
            var itemToUpdate = {
                id: this._idArray[rowIndex],
            };
            itemToUpdate = tslib_1.__assign({}, itemToUpdate, changedItem);
            this._datastore.update(itemToUpdate).then(function () {
                _this.reloadGridData();
            });
        };
        QueryAppContext.prototype.addNewItem = function (item) {
            var _this = this;
            this._datastore.create(item).then(function () {
                _this.reloadGridData();
            });
        };
        return QueryAppContext;
    }());
    exports.default = QueryAppContext;
});
//# sourceMappingURL=QueryAppContext.js.map