import WidgetBase from '@dojo/framework/widget-core/WidgetBase';
import { v, w } from '@dojo/framework/widget-core/d';
import TextInput from '@dojo/widgets/text-input';
import * as bs from 'rollun-common/dist/css/bootstrap.m.css';
export default class FluidForm extends WidgetBase {
    constructor() {
        super(...arguments);
        this.data = {};
        this.metadata = {};
    }
    render() {
        if (!this.isStarted) {
            this.data = Object.assign({}, this.data, this.properties.initialValues);
            this.isStarted = true;
        }
        return v('div', { classes: `${bs.dFlex} ${bs.flexColumn}` }, [
            v('form', {
                classes: `${bs.mb3}`
            }, this.properties.formConfig.map((formField) => {
                return v('div', {
                    classes: `${bs.formGroup}`
                }, [
                    v('div', {
                        classes: `${bs.colFormLabel}`
                    }, [
                        formField.label || formField.field
                    ]),
                    this.getEditorForFormField(formField),
                    this.getMessageForFormField(formField),
                ]);
            })),
            v('div', {
                classes: `${bs.p3} ${bs.borderTop}`,
                styles: { margin: '-1rem' }
            }, [
                v('button', {
                    classes: `${bs.btn}  ${bs.btnPrimary} ${bs.btnBlock}`,
                    onclick: () => {
                        this.properties.onFormSubmit(Object.assign({}, this.data));
                        this.data = {};
                    }
                }, [
                    'Confirm'
                ])
            ])
        ]);
    }
    getEditorForFormField(formField) {
        if (formField.editor) {
            return w(formField.editor, {
                value: this.data[formField.field], onChange: (value) => {
                    this.data[formField.field] = value;
                    if (formField.validator) {
                        this.metadata[formField.field] = Object.assign({}, this.metadata[formField.field], formField.validator(value));
                    }
                    else {
                        this.metadata[formField.field] = { valid: true };
                    }
                    this.invalidate();
                }
            });
        }
        else {
            return w(TextInput, {
                extraClasses: {
                    input: `${bs.formControl}`
                },
                invalid: (this.metadata[formField.field] && this.metadata[formField.field].valid === false),
                value: this.data[formField.field],
                onChange: (value) => {
                    this.data[formField.field] = value;
                    if (formField.validator) {
                        this.metadata[formField.field] = Object.assign({}, this.metadata[formField.field], formField.validator(value));
                    }
                    else {
                        this.metadata[formField.field] = { valid: true };
                    }
                    this.invalidate();
                }
            });
        }
    }
    getMessageForFormField(formField) {
        if (this.metadata[formField.field] && this.metadata[formField.field].message) {
            return v('div', {
                classes: `${bs.p1} ${this.metadata[formField.field].valid ? '' : bs.textDanger}`
            }, [
                this.metadata[formField.field].message
            ]);
        }
        return null;
    }
}
//# sourceMappingURL=FluidForm.mjs.map