import WidgetBase from '@dojo/framework/widget-core/WidgetBase';
import { v, w } from '@dojo/framework/widget-core/d';
import Select from 'rollun-ts-rql/dist/nodes/Select';
import Sort from 'rollun-ts-rql/dist/nodes/Sort';
import SelectNodeEditor from '../selectNodeEditor/SelectNodeEditor';
import SortNodeEditor from '../sortNodeEditor/SortNodeEditor';
import DropToRemoveNodeField from '../dropToRemoveNodeField/DropToRemoveNodeField';
import PossibleNodeFields from '../possibleNodeFields/PossibleNodeFields';
import AbstractLogicalNode from 'rollun-ts-rql/dist/nodes/logicalNodes/AbstractLogicalNode';
import ChildNodeCreationForm from '../queryQueryEditor/logicalEditor/ChildNodeCreationForm';
import RqlNodeFactory from '../../rqlNodeFactory/RqlNodeFactory';
import AbstractScalarNode from 'rollun-ts-rql/dist/nodes/scalarNodes/AbstractScalarNode';
import AbstractArrayNode from 'rollun-ts-rql/dist/nodes/arrayNodes/AbstractArrayNode';
import * as bs from 'rollun-common/dist/css/bootstrap.m.css';
import * as ownCss from './queryEditor.m.css';
import Dialog from '../../dialog/Dialog';
import QueryEditorContext, { QueryNodeNames } from '../../context/QueryEditorContext';
import ArrayNodeEditorContainer from '../../containers/queryBuilder/arrayNodeEditorContainer';
import ScalarNodeEditorContainer from '../../containers/queryBuilder/scalarNodeEditorContainer';
import LogicalNodeEditorContainer from '../../containers/queryBuilder/logicalNodeEditorContainer';
import ContextConfig from '../../common/ContextConfig';
export default class QueryEditor extends WidgetBase {
    constructor() {
        super(...arguments);
        this.openQueryCreationDialog = false;
        this.rqlNodeFactory = new RqlNodeFactory();
    }
    render() {
        if (!this.isStarted) {
            this.context = this.properties.context;
            this.context.query = this.properties.query;
            this.isStarted = true;
        }
        const nonQueryEditors = [
            v('div', { classes: `${bs.colMd4} ${bs.p0}` }, [
                w(PossibleNodeFields, { fieldNames: this.context.fieldNames })
            ]),
            v('div', { classes: `${bs.colMd3} ${bs.p0}` }, [
                this.renderSelectNode(this.context.query.selectNode)
            ]),
            v('div', { classes: `${bs.colMd3} ${bs.p0}` }, [
                this.renderSortNode(this.context.query.sortNode)
            ]),
            v('div', { classes: `${bs.colMd2} ${bs.p0}` }, [
                w(DropToRemoveNodeField, {
                    onNodeFieldRemove: (fieldName, nodeType) => {
                        this.removeFieldFromNode(fieldName, nodeType);
                    }
                })
            ])
        ];
        return v('div', {
            classes: `${bs.dFlex} ${bs.flexColumn} ${bs.mb3} ${bs.w100}`
        }, [
            v('div', {
                classes: `${bs.dFlex} ${bs.flexRow} ${bs.mb2} ${bs.m0} ${bs.row} ${bs.w100} ${ownCss.nonQueryEditors}`,
            }, nonQueryEditors),
            v('div', { classes: `${bs.dFlex} ${bs.justifyContentCenter} ${bs.mb1}` }, this.renderQueryNode(this.context.query.queryNode))
        ]);
    }
    renderSelectNode(node) {
        if (node) {
            const onRemove = () => {
                this.removeNode('select');
            };
            const onSelectNodeChange = (fields) => {
                this.context.setSelectNode(new Select(fields));
            };
            return w(SelectNodeEditor, {
                node, onRemove, fieldNames: this.context.fieldNames, onSelectNodeChange
            });
        }
        else {
            return v('div', {
                classes: `${bs.dFlex} ${bs.justifyContentCenter} ${bs.alignItemsCenter} ${bs.h100}`
            }, [
                v('button', {
                    classes: `${bs.btn} ${bs.btnLg} ${bs.btnLight} ${bs.mb1}`,
                    onclick: () => {
                        this.context.setSelectNode(new Select(['id']));
                    }
                }, ['Add select node'])
            ]);
        }
    }
    renderSortNode(node) {
        if (node) {
            const onSortNodeChange = (sortOptions) => {
                this.context.setSortNode(new Sort(sortOptions));
                this.invalidate();
            };
            const onRemove = () => {
                this.removeNode('sort');
            };
            return w(SortNodeEditor, { node, onRemove, onSortNodeChange });
        }
        else {
            return v('div', {
                classes: `${bs.dFlex} ${bs.justifyContentCenter} ${bs.alignItemsCenter} ${bs.h100}`
            }, [
                v('button', {
                    classes: `${bs.btn} ${bs.btnLg} ${bs.btnLight}  ${bs.mb1}`,
                    onclick: () => {
                        this.context.setSortNode(new Sort({ id: 1 }));
                    }
                }, ['Add sort node'])
            ]);
        }
    }
    renderQueryNode(node) {
        if (node) {
            const path = [0];
            const key = `query-${path[0]}`;
            switch (true) {
                case node instanceof AbstractLogicalNode:
                    return [
                        w(LogicalNodeEditorContainer, {
                            path,
                            key
                        })
                    ];
                case node instanceof AbstractScalarNode:
                    return [
                        w(ScalarNodeEditorContainer, {
                            path,
                            key
                        })
                    ];
                case node instanceof AbstractArrayNode:
                    return [
                        w(ArrayNodeEditorContainer, {
                            path,
                            key
                        })
                    ];
            }
        }
        else {
            return [
                v('button', {
                    classes: `${bs.btn} ${bs.btnLg} ${bs.btnLight}`,
                    onclick: () => {
                        this.openQueryCreationDialog = true;
                        this.invalidate();
                    }
                }, ['Add query node']),
                w(Dialog, {
                    title: 'Create new node',
                    isOpen: this.openQueryCreationDialog,
                    onClose: () => {
                        this.openQueryCreationDialog = false;
                        this.invalidate();
                    },
                    options: {
                        centered: true
                    }
                }, [
                    w(ChildNodeCreationForm, {
                        onChildNodeCreate: (nodeName, params) => {
                            this.openQueryCreationDialog = false;
                            this.context.setQueryNode(this.rqlNodeFactory.createNode(nodeName, params));
                        },
                        fieldNames: this.properties.fieldNames
                    })
                ])
            ];
        }
    }
    removeNode(queryNodeName) {
        switch (true) {
            case queryNodeName === 'select': {
                this.context.removeNode(QueryNodeNames.select);
                break;
            }
            case queryNodeName === 'sort': {
                this.context.removeNode(QueryNodeNames.sort);
                break;
            }
            case queryNodeName === 'limit': {
                this.context.removeNode(QueryNodeNames.limit);
                break;
            }
            case queryNodeName === 'query': {
                this.context.removeNode(QueryNodeNames.query);
                break;
            }
        }
    }
    removeFieldFromNode(fieldName, nodeType) {
        switch (nodeType) {
            case 'selectnode':
                const fieldNameIndex = this.context.query.selectNode.fields.indexOf(fieldName);
                if (fieldNameIndex !== -1) {
                    this.context.query.selectNode.fields.splice(fieldNameIndex, 1);
                    const newFields = [...this.context.query.selectNode.fields];
                    this.context.setSelectNode(new Select(newFields));
                }
                break;
            case 'sortnode':
                if (this.context.query.sortNode.sortOptions.hasOwnProperty(fieldName)) {
                    delete this.context.query.sortNode.sortOptions[fieldName];
                    const newSortOptions = Object.assign({}, this.context.query.sortNode.sortOptions);
                    this.context.setSortNode(new Sort(newSortOptions));
                }
                break;
        }
    }
}
QueryEditor.contextConfig = new ContextConfig(QueryEditorContext, []);
//# sourceMappingURL=QueryEditor.mjs.map