import * as tslib_1 from "tslib";
import WidgetBase from '@dojo/framework/widget-core/WidgetBase';
import { v, w } from '@dojo/framework/widget-core/d';
import AbstractLogicalNode from 'rollun-ts-rql/dist/nodes/logicalNodes/AbstractLogicalNode';
import AbstractScalarNode from 'rollun-ts-rql/dist/nodes/scalarNodes/AbstractScalarNode';
import AbstractArrayNode from 'rollun-ts-rql/dist/nodes/arrayNodes/AbstractArrayNode';
import RqlNodeFactory from '../../../rqlNodeFactory/RqlNodeFactory';
import * as bs from 'rollun-common/dist/css/bootstrap.m.css';
import * as fa from 'rollun-common/dist/css/fontawesome.m.css';
import * as faSolid from 'rollun-common/dist/css/solid.m.css';
import * as css from './logicalNode.m.css';
import ScalarNodeEditorContainer from '../../../containers/queryBuilder/scalarNodeEditorContainer';
import LogicalNodeEditorContainer from '../../../containers/queryBuilder/logicalNodeEditorContainer';
import ArrayNodeEditorContainer from '../../../containers/queryBuilder/arrayNodeEditorContainer';
import diffProperty from '@dojo/framework/widget-core/decorators/diffProperty';
import { undefinedSafeDiffNode } from '../../../common/functions';
import ChildNodeCreationFormDialogContainer from '../../../containers/queryBuilder/childNodeCreationFormDialogContainer';
export default class LogicalNodeEditor extends WidgetBase {
    constructor() {
        super();
        this.nodeFactory = new RqlNodeFactory();
    }
    render() {
        return v('div', { classes: `${bs.dFlex} ${bs.flexColumn} ${css.root}` }, [
            v('div', { classes: `${bs.dFlex} ${bs.flexRow} ${bs.bgInfo} ${bs.textWhite} ${bs.p1} ${css.controls}` }, [
                v('div', { classes: `${bs.dFlex} ${bs.justifyContentStart} ${css.titleContainer}` }, [
                    v('div', { classes: `${bs.m1} ${css.title}` }, [this.getNodeName()])
                ]),
                v('div', { classes: `${bs.dFlex} ${bs.justifyContentEnd} ${css.controlsButtonsContainer}` }, [
                    v('div', { classes: css.controlsButtons }, [
                        v('button', {
                            classes: `${bs.btn} ${bs.btnLight} ${bs.btnSm} ${bs.mx2}`,
                            onclick: () => {
                                this.addChildNode();
                            }
                        }, [
                            v('i', { classes: `${faSolid.fas} ${fa.faPlus}` })
                        ]),
                        v('button', {
                            classes: `${bs.btn} ${bs.btnDanger} ${bs.btnSm}`,
                            onclick: () => {
                                this.properties.onRemove(this.properties.path);
                            }
                        }, [
                            v('i', { classes: `${faSolid.fas} ${fa.faTimes}` })
                        ])
                    ])
                ])
            ]),
            v('div', { classes: `${bs.dFlex} ${bs.flexColumn} ${bs.p2} ${css.childNodesContainer}` }, this.properties.node.subNodes.map((node, index) => {
                const currentChildPath = this.properties.path.concat([index]);
                const key = `query-${currentChildPath.join('-')}`;
                switch (true) {
                    case (node instanceof AbstractLogicalNode):
                        return w(LogicalNodeEditorContainer, {
                            path: currentChildPath,
                            key,
                        });
                    case (node instanceof AbstractScalarNode):
                        return w(ScalarNodeEditorContainer, {
                            path: currentChildPath,
                            key
                        });
                    case (node instanceof AbstractArrayNode):
                        return w(ArrayNodeEditorContainer, {
                            path: currentChildPath,
                            key
                        });
                }
            })),
            w(ChildNodeCreationFormDialogContainer, { onChildNodeCreate: this.createChildNode.bind(this) })
        ]);
    }
    getNodeName() {
        return v('div', {}, [this.properties.node.name]);
    }
    addChildNode() {
        this.properties.openDialog();
    }
    createChildNode(nodeName, params) {
        this.properties.onAddChildNode(this.nodeFactory.createNode(nodeName, params));
        this.invalidate();
    }
}
tslib_1.__decorate([
    diffProperty('node', undefinedSafeDiffNode),
    tslib_1.__metadata("design:type", Function),
    tslib_1.__metadata("design:paramtypes", []),
    tslib_1.__metadata("design:returntype", Object)
], LogicalNodeEditor.prototype, "render", null);
//# sourceMappingURL=LogicalNodeEditor.mjs.map