import Query from 'rollun-ts-rql/dist/Query';
import Limit from 'rollun-ts-rql/dist/nodes/Limit';
import DatastoreDataUpdater from './dataUpdater/DatastoreDataUpdater';
import DatastoreCountUpdater from './dataUpdater/DatastoreCountUpdater';
import QueryManager from '../queryManager/QueryManager';
import HttpDatastore from 'rollun-ts-datastore/dist/HttpDatastore';
import DialogController from './DialogController';
export var QueryAppDialogNames;
(function (QueryAppDialogNames) {
    QueryAppDialogNames["addNewItemDialog"] = "addNewItemDialog";
    QueryAppDialogNames["editSelectedRowDialog"] = "editSelectedRowDialog";
    QueryAppDialogNames["editQueryDialog"] = "editQueryDialog";
})(QueryAppDialogNames || (QueryAppDialogNames = {}));
export default class QueryAppContext {
    constructor(invalidator, initialState) {
        this._invalidator = invalidator;
        this._grid = initialState.grid;
        this._queryManager = new QueryManager();
        this._queryManager.setQuery(new Query({ limit: new Limit(20, 0) }));
        this._datastore = new HttpDatastore(initialState.datastoreUrl);
        this._dataStoreDataUpdater = new DatastoreDataUpdater(this._datastore);
        this._countDataUpdater = new DatastoreCountUpdater(this._datastore);
        this._fieldsConfig = initialState.fieldsConfig || [];
        const addNewItemDialogId = QueryAppDialogNames.addNewItemDialog; // FIXME: why can`t i properly use enums in dialogController constructor params?
        const editSelectedRowDialogId = QueryAppDialogNames.editSelectedRowDialog;
        const editQueryDialogId = QueryAppDialogNames.editQueryDialog;
        const initialStatus = {};
        initialStatus[addNewItemDialogId] = { shown: false };
        initialStatus[editSelectedRowDialogId] = { shown: false };
        initialStatus[editQueryDialogId] = { shown: false };
        this._dialogs = new DialogController(invalidator, initialStatus);
        setTimeout(() => {
            this.reloadGridData();
        }, 1);
    }
    get query() {
        return this._queryManager.getQuery();
    }
    set query(query) {
        this._queryManager.setQuery(query);
    }
    get grid() {
        return this._grid;
    }
    set grid(gridValues) {
        this._grid = gridValues;
        this._invalidator();
    }
    get datastoreData() {
        return this._dataStoreDataUpdater.data;
    }
    get countData() {
        return this._countDataUpdater.data;
    }
    get datastoreDataLoadingStatus() {
        return this._dataStoreDataUpdater.loadingStatus;
    }
    get countDataLoadingStatus() {
        return this._countDataUpdater.loadingStatus;
    }
    get idArray() {
        return this._idArray;
    }
    get fieldsConfig() {
        return this._fieldsConfig;
    }
    get selectedGridRowIndex() {
        return this._grid.selectedRowIndex;
    }
    get dialogs() {
        return this._dialogs;
    }
    reloadGridData() {
        this._dataStoreDataUpdater.query = this._queryManager.getQuery();
        this._dataStoreDataUpdater.updateData().then(() => {
            this._invalidator();
        });
        this._countDataUpdater.query = this._queryManager.getQuery();
        this._countDataUpdater.updateData().then(() => {
            this._idArray = this.datastoreData.map(item => String(item.id));
            this._invalidator();
        });
        this._invalidator();
    }
    setQueryLimit(limitNode) {
        this._queryManager.appendQuery(limitNode);
        this.reloadGridData();
    }
    setQueryQuery(queryQuery) {
        this._queryManager.appendQuery(queryQuery);
        this.reloadGridData();
    }
    removeQueryQuery() {
        const oldQuery = this._queryManager.getQuery();
        this._queryManager.setQuery(new Query({
            select: oldQuery.selectNode,
            sort: oldQuery.sortNode,
            limit: oldQuery.limitNode,
        }));
        this.reloadGridData();
    }
    changeCellValue(rowIndex, columnIndex, value) {
        let itemToUpdate = {
            id: this._idArray[rowIndex],
        };
        const fieldName = Object.keys(this.datastoreData[0])[columnIndex];
        itemToUpdate[fieldName] = value;
        this._datastore.update(itemToUpdate).then(() => {
            this.reloadGridData();
        });
    }
    changeRowValue(rowIndex, changedItem) {
        let itemToUpdate = {
            id: this._idArray[rowIndex],
        };
        itemToUpdate = Object.assign({}, itemToUpdate, changedItem);
        this._datastore.update(itemToUpdate).then(() => {
            this.reloadGridData();
        });
    }
    addNewItem(item) {
        this._datastore.create(item).then(() => {
            this.reloadGridData();
        });
    }
}
//# sourceMappingURL=QueryAppContext.mjs.map