import WidgetBase from '@dojo/framework/widget-core/WidgetBase';
import { v } from '@dojo/framework/widget-core/d';
import * as css from './dropToRemoveField.m.css';
import * as bs from 'rollun-common/dist/css/bootstrap.m.css';
import * as fa from 'rollun-common/dist/css/fontawesome.m.css';
import * as faSolid from 'rollun-common/dist/css/solid.m.css';
import * as commonCss from '../common/common.m.css';
import { QueryNodeNames } from '../../context/QueryEditorContext';
export default class DropToRemoveNodeField extends WidgetBase {
    constructor() {
        super(...arguments);
        this.awaitingDrop = false;
        this.validDropTarget = false;
    }
    render() {
        let classes = `${css.root} ${bs.card} ${bs.h100} ${bs.m1} ${commonCss.transparentBorder}`;
        if (this.awaitingDrop === true) {
            classes += this.validDropTarget ? ` ${commonCss.validBorder}` : ` ${commonCss.invalidBorder}`;
        }
        return v('div', {
            classes: classes,
            ondragover: (event) => {
                this.checkDropPossibility(event);
            },
            ondragleave: (event) => {
                this.disableDropTarget(event);
            },
            ondrop: (event) => {
                this.removeDroppedNodeFromSelectedNodes(event);
                this.disableDropTarget(event);
            }
        }, [
            v('div', { classes: `${bs.cardBody} ${bs.p3} ${bs.h100} ${bs.border}` }, [
                v('span', { classes: `${css.title} ${bs.cardTitle}` }, ['Drop field to remove it']),
                v('div', { classes: `${bs.cardText} ${bs.dFlex} ${bs.justifyContentCenter} ${bs.alignItemsCenter} ${css.iconAligner}` }, [
                    v('div', {}, [
                        v('i', { classes: `${faSolid.fas} ${fa.faTrashAlt} ${fa.fa3x}` })
                    ])
                ])
            ])
        ]);
    }
    checkDropPossibility(event) {
        event.preventDefault();
        if (event.dataTransfer.types.indexOf('nodefieldname') !== -1) {
            this.awaitingDrop = true;
            this.validDropTarget = true;
            this.invalidate();
            return false;
        }
        this.invalidate();
        return true;
    }
    disableDropTarget(event) {
        this.awaitingDrop = false;
        this.validDropTarget = false;
        this.invalidate();
    }
    removeDroppedNodeFromSelectedNodes(event) {
        const nodeFieldName = event.dataTransfer.getData('nodefieldname');
        let nodeType;
        if (event.dataTransfer.types.indexOf('selectnode') !== -1) {
            nodeType = QueryNodeNames.select;
        }
        else {
            nodeType = QueryNodeNames.sort;
        }
        this.properties.onNodeFieldRemove(nodeFieldName, nodeType);
    }
}
//# sourceMappingURL=DropToRemoveNodeField.mjs.map