(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var DialogController = /** @class */ (function () {
        function DialogController(invalidator, initialStatus) {
            this._invalidator = invalidator;
            this._dialogs = new Map(Object.entries(initialStatus));
        }
        DialogController.prototype.show = function (dialogId) {
            var currentStatus = this._dialogs.get(dialogId);
            if (currentStatus) {
                currentStatus.shown = true;
                this._dialogs.set(dialogId, currentStatus);
                this._invalidator();
            }
        };
        DialogController.prototype.hide = function (dialogId) {
            var currentStatus = this._dialogs.get(dialogId);
            if (currentStatus) {
                currentStatus.shown = false;
                this._dialogs.set(dialogId, currentStatus);
                this._invalidator();
            }
        };
        DialogController.prototype.has = function (dialogId) {
            return this._dialogs.has(dialogId);
        };
        DialogController.prototype.get = function (dialogId) {
            return this._dialogs.get(dialogId);
        };
        DialogController.prototype.set = function (dialogId, status) {
            this._dialogs.set(dialogId, status);
            this._invalidator();
        };
        return DialogController;
    }());
    exports.default = DialogController;
});
//# sourceMappingURL=DialogController.js.map