(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "tslib", "rollun-ts-rql/dist/Query", "rollun-ts-rql/dist/nodes/Select", "rollun-ts-rql/dist/nodes/Sort", "rollun-ts-rql/dist/nodes/logicalNodes/AbstractLogicalNode", "./DialogController"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var tslib_1 = require("tslib");
    var Query_1 = require("rollun-ts-rql/dist/Query");
    var Select_1 = require("rollun-ts-rql/dist/nodes/Select");
    var Sort_1 = require("rollun-ts-rql/dist/nodes/Sort");
    var AbstractLogicalNode_1 = require("rollun-ts-rql/dist/nodes/logicalNodes/AbstractLogicalNode");
    var DialogController_1 = require("./DialogController");
    var QueryNodeNames;
    (function (QueryNodeNames) {
        QueryNodeNames["select"] = "select";
        QueryNodeNames["sort"] = "sort";
        QueryNodeNames["limit"] = "limit";
        QueryNodeNames["query"] = "query";
    })(QueryNodeNames = exports.QueryNodeNames || (exports.QueryNodeNames = {}));
    var QueryEditorDialogNames;
    (function (QueryEditorDialogNames) {
        QueryEditorDialogNames["addNewNodeDialog"] = "addNewNodeDialog";
    })(QueryEditorDialogNames = exports.QueryEditorDialogNames || (exports.QueryEditorDialogNames = {}));
    var QueryEditorContext = /** @class */ (function () {
        function QueryEditorContext(invalidator) {
            this._invalidator = invalidator;
            this._fieldNames = [];
            var initialStatus = {};
            initialStatus[QueryEditorDialogNames.addNewNodeDialog] = { shown: false };
            this._dialogs = new DialogController_1.default(invalidator, initialStatus);
        }
        Object.defineProperty(QueryEditorContext.prototype, "onApplyQuery", {
            get: function () {
                return this._onApplyQuery;
            },
            set: function (value) {
                this._onApplyQuery = value;
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryEditorContext.prototype, "query", {
            get: function () {
                return this._query;
            },
            set: function (query) {
                this._query = query;
                this._invalidator();
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryEditorContext.prototype, "fieldNames", {
            get: function () {
                return this._fieldNames;
            },
            set: function (value) {
                if (value.length > this._fieldNames.length) {
                    this._fieldNames = value;
                    this._invalidator();
                }
            },
            enumerable: true,
            configurable: true
        });
        Object.defineProperty(QueryEditorContext.prototype, "dialogs", {
            get: function () {
                return this._dialogs;
            },
            enumerable: true,
            configurable: true
        });
        QueryEditorContext.prototype.applyQuery = function (query) {
            this._onApplyQuery(query);
        };
        QueryEditorContext.prototype.setQueryNode = function (node) {
            var oldQuery = this.query;
            this._query = new Query_1.default({
                select: oldQuery.selectNode,
                sort: oldQuery.sortNode,
                limit: oldQuery.limitNode,
                query: node
            });
            this._invalidator();
        };
        QueryEditorContext.prototype.setSelectNode = function (node) {
            var oldQuery = this.query;
            this._query = new Query_1.default({
                select: node,
                sort: oldQuery.sortNode,
                limit: oldQuery.limitNode,
                query: oldQuery.queryNode
            });
            this._invalidator();
        };
        QueryEditorContext.prototype.setSortNode = function (node) {
            var oldQuery = this.query;
            this._query = new Query_1.default({
                select: oldQuery.selectNode,
                sort: node,
                limit: oldQuery.limitNode,
                query: oldQuery.queryNode
            });
            this._invalidator();
        };
        QueryEditorContext.prototype.removeNode = function (queryNodeName) {
            var oldQuery = this.query;
            switch (true) {
                case queryNodeName === QueryNodeNames.select: {
                    this._query = new Query_1.default({
                        sort: oldQuery.sortNode,
                        limit: oldQuery.limitNode,
                        query: oldQuery.queryNode
                    });
                    break;
                }
                case queryNodeName === QueryNodeNames.sort: {
                    this._query = new Query_1.default({
                        select: oldQuery.selectNode,
                        limit: oldQuery.limitNode,
                        query: oldQuery.queryNode
                    });
                    break;
                }
                case queryNodeName === QueryNodeNames.limit: {
                    this._query = new Query_1.default({
                        select: oldQuery.selectNode,
                        sort: oldQuery.sortNode,
                        query: oldQuery.queryNode
                    });
                    break;
                }
                case queryNodeName === QueryNodeNames.query: {
                    this._query = new Query_1.default({
                        select: oldQuery.selectNode,
                        sort: oldQuery.sortNode,
                        limit: oldQuery.limitNode,
                    });
                    break;
                }
            }
            this._invalidator();
        };
        QueryEditorContext.prototype.removeFieldFromNode = function (fieldName, nodeName) {
            var oldQuery = this.query;
            switch (nodeName) {
                case QueryNodeNames.select:
                    var fieldNameIndex = oldQuery.selectNode.fields.indexOf(fieldName);
                    if (fieldNameIndex !== -1) {
                        oldQuery.selectNode.fields.splice(fieldNameIndex, 1);
                        var newFields = tslib_1.__spread(oldQuery.selectNode.fields);
                        this.setSelectNode(new Select_1.default(newFields));
                    }
                    break;
                case QueryNodeNames.sort:
                    if (oldQuery.sortNode.sortOptions.hasOwnProperty(fieldName)) {
                        delete oldQuery.sortNode.sortOptions[fieldName];
                        var newSortOptions = Object.assign({}, oldQuery.sortNode.sortOptions);
                        this.setSortNode(new Sort_1.default(newSortOptions));
                    }
                    break;
            }
            this._invalidator();
        };
        QueryEditorContext.prototype.getNodeForPath = function (path) {
            var query = this.query;
            var currentNode = query.queryNode;
            path.forEach(function (pathFragment, index) {
                if (index === 0) {
                    return;
                }
                if (currentNode instanceof AbstractLogicalNode_1.default) {
                    currentNode = currentNode.subNodes[pathFragment];
                }
                else {
                    throw new Error("Invalid path: " + path.join(' '));
                }
            });
            return currentNode;
        };
        QueryEditorContext.prototype.hasNodeForPath = function (path) {
            try {
                this.getNodeForPath(path);
                return true;
            }
            catch (error) {
                return false;
            }
        };
        QueryEditorContext.prototype.removeNodeForPath = function (path) {
            if (path.length === 1 && path[0] === 0) {
                this.removeNode(QueryNodeNames.query);
            }
            else {
                var parentNodePath = path.slice(0, path.length - 1);
                var parentNode = this.getNodeForPath(parentNodePath);
                if (parentNode instanceof AbstractLogicalNode_1.default) {
                    parentNode.removeNode(path[path.length - 1]);
                    this._invalidator();
                }
                else {
                    throw new Error("Node with path " + path.join(' ') + " doesnt have children");
                }
            }
        };
        QueryEditorContext.prototype.addNodeForPath = function (node, path) {
            var parentNodePath = path.slice(0, path.length - 1);
            var parentNode = this.getNodeForPath(parentNodePath);
            if (parentNode instanceof AbstractLogicalNode_1.default) {
                parentNode.addNode(node);
                this._invalidator();
            }
            else {
                throw new Error("Node with path " + path.join(' ') + " can't have children");
            }
        };
        return QueryEditorContext;
    }());
    exports.default = QueryEditorContext;
});
//# sourceMappingURL=QueryEditorContext.js.map