(function (factory) {
    if (typeof module === "object" && typeof module.exports === "object") {
        var v = factory(require, exports);
        if (v !== undefined) module.exports = v;
    }
    else if (typeof define === "function" && define.amd) {
        define(["require", "exports", "rollun-ts-rql/dist/Query", "lodash", "rollun-ts-rql/dist/nodes/AbstractQueryNode", "rollun-ts-rql/dist/nodes/Select", "rollun-ts-rql/dist/nodes/logicalNodes/And", "rollun-ts-rql/dist/nodes/Sort", "rollun-ts-rql/dist/nodes/Limit"], factory);
    }
})(function (require, exports) {
    "use strict";
    Object.defineProperty(exports, "__esModule", { value: true });
    var Query_1 = require("rollun-ts-rql/dist/Query");
    var _ = require("lodash");
    var AbstractQueryNode_1 = require("rollun-ts-rql/dist/nodes/AbstractQueryNode");
    var Select_1 = require("rollun-ts-rql/dist/nodes/Select");
    var And_1 = require("rollun-ts-rql/dist/nodes/logicalNodes/And");
    var Sort_1 = require("rollun-ts-rql/dist/nodes/Sort");
    var Limit_1 = require("rollun-ts-rql/dist/nodes/Limit");
    var QueryManager = /** @class */ (function () {
        function QueryManager() {
        }
        QueryManager.prototype.setQuery = function (query) {
            this.query = _.cloneDeep(query);
        };
        QueryManager.prototype.getQuery = function () {
            return _.cloneDeep(this.query);
        };
        QueryManager.prototype.appendQuery = function (node) {
            if (node instanceof AbstractQueryNode_1.default) {
                this.addQueryNodeToQuery(node);
            }
            else {
                this.addNotQueryNodeToQuery(node);
            }
        };
        QueryManager.prototype.setQueryQuery = function (node) {
            var oldQuery = this.getQuery();
            this.setQuery(new Query_1.default({
                select: oldQuery.selectNode,
                sort: oldQuery.sortNode,
                limit: oldQuery.limitNode,
                query: node
            }));
        };
        QueryManager.prototype.addQueryNodeToQuery = function (node) {
            var oldQuery = this.getQuery();
            var newQueryQueryNode;
            if (oldQuery.queryNode) {
                newQueryQueryNode = new And_1.default([oldQuery.queryNode, node]);
            }
            else {
                newQueryQueryNode = node;
            }
            this.setQuery(new Query_1.default({
                select: oldQuery.selectNode,
                sort: oldQuery.sortNode,
                limit: oldQuery.limitNode,
                query: newQueryQueryNode
            }));
        };
        QueryManager.prototype.addNotQueryNodeToQuery = function (node) {
            var currentQuery = this.getQuery();
            var newQuery;
            switch (true) {
                case node instanceof Select_1.default:
                    var castedSelectNode = node;
                    newQuery = new Query_1.default({
                        select: castedSelectNode,
                        sort: currentQuery.sortNode,
                        limit: currentQuery.limitNode,
                        query: currentQuery.queryNode
                    });
                    break;
                case (node instanceof Sort_1.default):
                    var castedSortNode = node;
                    newQuery = new Query_1.default({
                        select: currentQuery.selectNode,
                        sort: castedSortNode,
                        limit: currentQuery.limitNode,
                        query: currentQuery.queryNode
                    });
                    break;
                case node instanceof Limit_1.default:
                    var castedLimitNode = node;
                    newQuery = new Query_1.default({
                        select: currentQuery.selectNode,
                        sort: currentQuery.sortNode,
                        limit: castedLimitNode,
                        query: currentQuery.queryNode
                    });
                    break;
                default:
                    newQuery = currentQuery;
            }
            this.setQuery(newQuery);
        };
        return QueryManager;
    }());
    exports.default = QueryManager;
});
//# sourceMappingURL=QueryManager.js.map